"as_radians" <-
function(theta=0) {

  #=======================================================
  #
  #  TITLE:     CONVERT ANGLE IN DEGREES TO RADIANS
  #  FUNCTION:  as_radians()
  #  AUTHOR:    TARMO K. REMMEL 
  #  DATE:      17 JANUARY 2006
  #  CALLS:     NA
  #  NEEDS:     
  #  NOTES:     
  #
  #=======================================================

  return(theta*pi/180)
  
} # END FUNCTION: as_radians
